@@ -1,6 +1,5 @@
 import asyncio
-import datetime
-import calendar
+import dateutil.parser as dateparser
 import functools
 import json
 import os
@@ -198,29 +197,19 @@ class FinXRest:
         return return_df
 
     def _calc_years_to_expiry(self, row):
-        print("row", row)
         instrument_name = row['instrument_name']
         years_to_expiry = 0.0
         try:
-            day_value = int(instrument_name.split("-")[1][0:2])
-            month_value = instrument_name.split("-")[1][2:5]
-            year_value = int(instrument_name.split("-")[1][5:8])
-            date_string = str(year_value) + '/' + month_value + '/' + str(day_value)
-            expiry_unix = datetime.datetime.strptime(date_string, '%y/%b/%d').timestamp()
+            expiry_unix = int(dateparser.parse(instrument_name.split("-")[1]).timestamp())
         except:
-            return None
+            print('error parsing:', instrument_name.split("-")[1])
         try:
-            day_value = int(instrument_name.split("-")[1][0:1])
-            month_value = instrument_name.split("-")[1][1:4]
-            year_value = int(instrument_name.split("-")[1][4:7])
-            date_string = str(year_value) + '/' + month_value + '/' + str(day_value)
-            expiry_unix = datetime.datetime.strptime(date_string, '%y/%b/%d').timestamp()
+            unixtime_difference = int(expiry_unix) - time.time()
+            years_to_expiry = unixtime_difference / 60 / 60 / 24 / 365
         except:
-            return None
-        try:
-            years_to_expiry = (expiry_unix - time.time()) / 60 / 60 / 24 / 365
-        except:
-            return None
+            print('error calculating time_to_expiry:', instrument_name)
+        if years_to_expiry < 0:
+            years_to_expiry = -1
         return years_to_expiry
 
     def _parse_strike_price(self, row):
@@ -231,8 +220,9 @@ class FinXRest:
         df = pd.DataFrame(await self.get_options_timeslice(timeslice_datestamp, timeslice_width_seconds, underlying_symbol))
         print('vol_surface_inputs raw:', df)
         df['years_to_expiry'] = df.apply(lambda row: self._calc_years_to_expiry(row), axis=1)
-        df['strike_price'] = df.apply(lambda row: self._parse_strike_price(row), axis=1)
-        output_df = df[['years_to_expiry', 'strike_price', 'mark_iv']]
+        df_filtered = df[df['years_to_expiry'] > 0]
+        df_filtered['strike_price'] = df_filtered.apply(lambda row: self._parse_strike_price(row), axis=1)
+        output_df = df_filtered[['years_to_expiry', 'strike_price', 'mark_iv']].copy()
         output_df.rename(columns={"years_to_expiry": "expiration", "strike_price": "price", "mark_iv": "price"})
         # must be expiration,strike,price
         #,redis_key,underlying_price,underlying_index,timestamp,state,settlement_price,open_interest,min_price,max_price,mark_price,mark_iv,last_price,interest_rate,instrument_name,index_price,estimated_delivery_price,bid_iv,best_bid_price,best_bid_amount,best_ask_price,best_ask_amount,ask_iv,vega,theta,rho,gamma,delta,volume,price_change,low,high
